@@ -1,4 +1,8 @@
-my $env = translate('env');
+use utf8;
+use warnings;
+no warnings 'redefine';
+use vars qw($env);
+$env = translate('env');
 print '<div class="ShowTables marginTop">';
 print "<b>$env</b>";
 print '<table align ="center" border ="0" cellpadding ="2" cellspacing="2" summary="env">';
@@ -10,3 +14,4 @@ foreach my $key (keys %ENV) {
       . '</td></tr>';
 }
 print '</table></div>';
+1;
\ No newline at end of file
