@@ -1,3 +1,5 @@
+use utf8;
+use warnings;
 no warnings 'redefine';
 use vars qw(@t @menuNavi @m_aT1 $treeview);
 @menuNavi = $m_oDatabase->fetch_AoH(
