@@ -1,5 +1,8 @@
+use utf8;
+use warnings;
 no warnings 'redefine';
-MySQL::Admin::Settings::loadSettings("$m_hrSettings->{cgi}{bin}/config/settings.pl");
+use vars qw($TITLE);
+loadSettings("$m_hrSettings->{cgi}{bin}/config/settings.pl");
 use vars qw($TITLE);
 $TITLE = translate('settings');
 show_form(
