@@ -42,12 +42,12 @@ print qq(<?xml version="1.0" encoding="UTF-8"?><xml>\n\n);
 
 SWITCH:{
   if($m_sAction eq 'save'){
-    eval('
+    eval{
       use Authen::Captcha;
       my $captcha = Authen::Captcha->new(data_folder   => "$m_hrS->{cgi}{bin}/config/",
 					  output_folder => "$m_hrS->{cgi}{DocumentRoot}/images");
       $m_nSkipCaptch = $captcha->check_code(param("captcha"), param("md5"));
-    ');
+    };
     $m_nSkipCaptch = 1 if $@;
     if($m_nSkipCaptch <= 0){
       &install();
@@ -55,8 +55,7 @@ SWITCH:{
     }
     if( param('username') eq $m_hrS->{admin}{name}  &&  param('password') eq $m_hrS->{admin}{password} ){
     my $m_sFile = '';
-    eval(
-    q|
+    eval{
 	my %conf = (
 	  name => $m_hrS->{database}{name},
 	  host => $m_hrS->{database}{hsot},
@@ -79,12 +78,12 @@ SWITCH:{
 	    $md5->add($m_hrS->{admin}{name});
 	    $md5->add($m_hrS->{admin}{password});
 	    my $fingerprint = $md5->hexdigest();
-	    $m_oDatabase->void(qq/insert into users (`user`,`pass`,`right`,`id`) values(?,?,5,?)/, 'admin', $fingerprint,'2');
+	    $dDatabase->void(qq/insert into users (`user`,`pass`,`right`,`id`) values(?,?,5,?)/, 'admin', $fingerprint,'2');
 	} else {
 	    warn $@;
-	    $m_oDatabase->void(qq/insert into users (`user`,`pass`,`right`,`id`) values('admin','0008e525bc0894a780297b7f3aed6f58','5','2')/);
+	    $dDatabase->void(qq/insert into users (`user`,`pass`,`right`,`id`) values('admin','0008e525bc0894a780297b7f3aed6f58','5','2')/);
 	}
-      |);
+      };
       if( $@ ){
         &install();
       }else{
@@ -101,7 +100,7 @@ SWITCH:{
 }
 sub install{
     my $authen ='';
-    eval(q{
+    eval{
       my $right_captcha_text = 'Right';
       my $wrong_captcha_text = 'Wrong';
       use Authen::Captcha;
@@ -113,7 +112,7 @@ sub install{
       $authen = qq|<input size="5" type="hidden" name="md5" value="$md5sum"/>
       <img src="images/$md5sum.png" border="0"  style="vertical-align:middle;margin:0%">
       <input style="width:35px;" autocomplete="off" onkeypress="if(enter(event))return false;" type="text" size="3" data-regexp="|.'/^.{3}$/'.qq|" data-error="$wrong_captcha_text" data-right="$right_captcha_text"  name="captcha"/>|;
-    });
+    };
   print qq|<output id="errorMessage"><![CDATA[$@]]></output>| if $@;
   print qq|<output id="content">
   <![CDATA[
