@@ -1,7 +1,8 @@
+
 /*
 =head2 NAME
 
-    MySQL::Admin 
+    MySQL::Admin::Documentation
 
 =head2 SYNOPSIS
 
@@ -206,7 +207,7 @@ outId, tabId, title set L<requestURI>
 function loadPage(inXml, inXsl, outId, tabId, title) {
     xml = typeof inXml == 'object' ? inXml : loadXMLDoc(inXml);
     xsl = typeof inXsl == 'object' ? inXsl : loadXMLDoc(inXsl);
-    if (window.ActiveXObject) {
+    if (typeof XSLTProcessor == 'undefined') { //window.ActiveXObject
         ex = xml.transformNode(xsl);
         $(outId).innerHTML = ex;
     } else if (document.implementation && document.implementation.createDocument) {
@@ -1671,7 +1672,7 @@ function checkButton(id,parent){
 /*
 =head2 COPYRIGHT
 
-    Copyright (C) 2006-2015 by Hr. Dirk Lindner
+    Copyright (C) 2006-2016 by Hr. Dirk Lindner
 
     perl -e'sub lze_Rocks{print/(...)/ for shift;}sub{&{"@_"}}->("lze_Rocks")'
 
